asr.hse
=======

.. automodule:: asr.hse

   
   
   .. rubric:: Functions

   
   .. autofunction:: MP_interpolate
   .. autofunction:: bs_hse
   .. autofunction:: get_kpts_size
   .. autofunction:: hse
   .. autofunction:: hse_spinorbit
   .. autofunction:: webpanel
   
   

   
   
   

   
   
   